@@ -61,6 +61,7 @@ except ImportError:
     chardet = None
 
 from .gziphttp import GZipProcessor
+from .htmlcleanup import reduce_zalgo
 
 # All of the writers(epub,html,txt) and adapters(ffnet,twlt,etc)
 # inherit from Configurable.  The config file(s) uses ini format:
@@ -267,13 +268,13 @@ def get_valid_set_options():
                'always_use_forumtags':(base_xenforo_list,None,boollist),
                'use_reader_mode':(base_xenforo_list,None,boollist),
                'author_avatar_cover':(base_xenforo_list,None,boollist),
-               'remove_spoilers':(base_xenforo_list+['royalroadl.com'],None,boollist),
-               'legend_spoilers':(base_xenforo_list+['royalroadl.com'],None,boollist),
+               'remove_spoilers':(base_xenforo_list+['royalroad.com'],None,boollist),
+               'legend_spoilers':(base_xenforo_list+['royalroad.com'],None,boollist),
                'apocrypha_to_omake':(base_xenforo_list,None,boollist),
                'replace_failed_smilies_with_alt_text':(base_xenforo_list,None,boollist),
                'use_threadmark_wordcounts':(base_xenforo_list,None,boollist),
                'fix_pseudo_html': (['webnovel.com'], None, boollist),
-               'fix_excess_space': (['lightnovelgate.com', 'novelall.com'], ['epub', 'html'], boollist)
+               'fix_excess_space': (['novelonlinefull.com', 'novelall.com'], ['epub', 'html'], boollist)
                }
 
     return dict(valdict)
@@ -480,6 +481,7 @@ def get_valid_keywords():
                  'fix_pseudo_html',
                  'fix_excess_space',
                  'ignore_chapter_url_list',
+                 'max_zalgo',
                  ])
 
 # *known* entry keywords -- or rather regexps for them.
@@ -1006,6 +1008,14 @@ class Configuration(configparser.SafeConfigParser):
             sys.stdout.write('.')
             sys.stdout.flush()
 
+    def _do_reduce_zalgo(self,data):
+        max_zalgo = int(self.getConfig('max_zalgo',-1))
+        if max_zalgo > -1:
+            logger.debug("Applying max_zalgo:%s"%max_zalgo)
+            return reduce_zalgo(data,max_zalgo)
+        else:
+            return data
+
     # Assumes application/x-www-form-urlencoded.  parameters, headers are dict()s
     def _postUrl(self, url,
                  parameters={},
@@ -1044,7 +1054,7 @@ class Configuration(configparser.SafeConfigParser):
         self.opener.addheaders = [('User-Agent', self.getConfig('user_agent')),
                                   ('X-Clacks-Overhead','GNU Terry Pratchett')]
 
-        data = self._decode(self.opener.open(req,None,float(self.getConfig('connect_timeout',30.0))).read())
+        data = self._do_reduce_zalgo(self._decode(self.opener.open(req,None,float(self.getConfig('connect_timeout',30.0))).read()))
         self._progressbar()
         ## postURL saves data to the pagecache *after* _decode() while
         ## fetchRaw saves it *before* _decode()--because raw.
@@ -1154,7 +1164,7 @@ class Configuration(configparser.SafeConfigParser):
                                                       usecache=usecache,
                                                       extrasleep=extrasleep,
                                                       referer=referer)
-                return (self._decode(data),opened)
+                return (self._do_reduce_zalgo(self._decode(data)),opened)
             except HTTPError as he:
                 excpt=he
                 if he.code in (403,404,410):
